IpAddress class

Inheritance

Constructors

IpAddress({RequestType type = RequestType.text})
The main ipAddress constructor which will be called to get the ipAddress.

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestType ↔ RequestType
The type of request.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ RequestType
The type of request.
getter/setter pair

Methods

getIp() → Future
Get ip address depending on the requestType.
getIpAddress() → Future
Get Ip address of the system based on requestType.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

version ↔ String
Current version of this library.
getter/setter pair