NetworkHandler class abstract

The network handler which will handle all the data related work.

Implementers

Constructors

NetworkHandler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIpAddressJson() → Future<Map<String, dynamic>>
Get IpAddress in map format.
getIpAddressText() → Future<String>
Get IpAddress in text format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited